===============================
os-cloud-config
===============================

Configuration for OpenStack clouds.

* Free software: Apache license
* Documentation: http://docs.openstack.org/developer/os-cloud-config

Features
--------

* TODO